from kof_api.Animal import Animal


class Pig(Animal):
	def __init__(self):
		self.name = "Pig"
		self.can_carry = False
		self.weight = 145
		self.max_capacity = 0
		
		super().__init__(self.name, self.can_carry, self.weight, self.max_capacity)


from kof_api.Sword import Sword
from kof_api.Math import Math

math = Math()


class BronzeSSword(Sword):
	def __init__(self):
		self.name = "Bronze Short Sword"
		self.atk = 3
		self.weight = math.convert_kg_lb(.6)
		
		super().__init__(self.name, self.atk, self.weight)
	


from kof_api.Sword import Sword
from kof_api.Math import Math

math = Math()


class BronzeLSword(Sword):
	def __init__(self):
		self.name = "Bronze Long Sword"
		self.atk = 3.5
		self.weight = math.convert_kg_lb(1.4)
		
		super().__init__(self.name, self.atk, self.weight)



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.8'
DESCRIPTION = 'API for Kingdoms of Fortune.'

# Setting up
setup(
    name="kof_api",
    version=VERSION,
    author="GalaxyIndieDev",
    author_email="<zachnichelson304@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'api', 'kof', 'video game'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ]
)